sudo apt-get update

sudo apt-get install python python-xapian python-apt python-cluster python-simplejson python-numpy apt-xapian-index python-xdg debtags python-pip python-sklearn python-matplotlib python-stemmer python-fuzzywuzzy -y

sudo update-apt-xapian-index

sudo pip install setuptools
